'use strict'

// все предметы
let pricebase_items = {};
// самый высокий id из имеющихся предметов
let pricebase_last_item_id = 0;
// последние цены после парсинга
let pricebase_last_scan_prices = {};
let pricebase_last_scan_info = {};

// загрузка файла со всеми предметами
function loadItemsFile(is_price_loading, body, callback) {

    if (typeof callback !== 'function') {
        callback = function(){};
    }

    if (typeof body === 'function') {
        callback = body;
        body = null;
    }

    //is_price_loading == true значит что функция вызвана при загрузке цен

    pricebase_last_item_id = 0

    // сделать запрос на получение последней версии предметов
    api.request({
        url : '/db/pricebase/items',
        method : 'GET',
        prefix : false,
        data : {
            v : pricebase_items_version
        }
    }, function (err, res, data) {

        if (err) {
            return callback({
                success : false,
                error : 'Unknown error'
            });
        }

        for (let k in data) {
            let id = Number(k);

            if (id > pricebase_last_item_id) pricebase_last_item_id = id;

            pricebase_items[k] = data[k];
        }

        if (is_price_loading) {

            // передать обработку дальше
            return processPricesRequest(body, callback);

        } else {
            return callback({
                success : true
            });
        }


    });

}

function loadPrices(service, category, domain, callback) {

    pricebase_last_scan_prices = {};
    pricebase_last_scan_info = {};

    settings.service = service;
    settings.category = category;
    saveSettings();

    api.request({
        url : '/trade-assistant/load/prices',
        data : {
            last_item_id : pricebase_last_item_id,
            domain : domain,
            service : {
                name : service,
                updated : settings.updated
            }
        }
    }, function (err, res, body) {

        if (err) {
            return callback({
                success : false,
                error : 'Unknown error' // тут могут быть и известные ошибки
            });
        }


        if (body.items_info && body.items_info.version) {
            // нужно обновить файл с предметами прежде чем продолжать
            pricebase_items_version = body.items_info.version;

            return loadItemsFile(true, body, callback);
        }

        return processPricesRequest(body, callback);

    });

}

function processPricesRequest(body, callback) {

    // добавим предметы что не присутствуют в последней версии файла
    if (body.items_info && body.items_info.list) {

        for (let k in body.items_info.list) {
            let id = Number(k);

            if (id > pricebase_last_item_id) pricebase_last_item_id = id;

            pricebase_items[k] = body.items_info.list[k];
        }

    }

    let result_items = {};

    let total_items = 0;

    for (let i = 0, l = body.result.length; i < l; i++) {
        let item = body.result[i];

        if (!pricebase_items[ item.i ]) continue;

        result_items[ pricebase_items[ item.i ].m ] = Object.assign(item, { skin : pricebase_items[ item.i ] });
        total_items++;
    }

    pricebase_last_scan_prices = result_items;
    pricebase_last_scan_info = body.info;

    return callback({
        success : true,
        info : body.info,
        items : result_items,
        total_items : total_items
    });

}

function loadFavourite(callback) {

    api.request({
        url : '/favourite/load',
        data : {
            service: "trade-assistant"
        }
    }, function (err, res, body) {

        if (err) {
            return callback({
                success : false
            });
        }

        return callback({
            success : true,
            items : body.result
        });

    });

}

function addFavourite(item, callback) {

    api.request({
        url : '/favourite/add',
        data : {
            service: "trade-assistant",
            name : item
        }
    }, function (err, res, body) {

        if (err) {
            return callback({
                success : false
            });
        }

        return callback({
            success : true,
            name : item,
            id : body.id
        });

    });

}

function removeFavourite(item, callback) {

    api.request({
        url : '/favourite/remove',
        data : {
            service: "trade-assistant",
            id : item
        }
    }, function (err, res, body) {

        if (err) {
            return callback({
                success : false
            });
        }

        return callback({
            success : true,
            name : item
        });

    });

}